# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['NetworkVSphereArgs', 'NetworkVSphere']

@pulumi.input_type
class NetworkVSphereArgs:
    def __init__(__self__, *,
                 cidr: Optional[pulumi.Input[str]] = None,
                 default_gateway: Optional[pulumi.Input[str]] = None,
                 default_ipv6_gateway: Optional[pulumi.Input[str]] = None,
                 dns_search_domains: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 dns_server_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 domain: Optional[pulumi.Input[str]] = None,
                 ipv6_cidr: Optional[pulumi.Input[str]] = None,
                 is_default: Optional[pulumi.Input[bool]] = None,
                 is_public: Optional[pulumi.Input[bool]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkVSphereTagArgs']]]] = None):
        """
        The set of arguments for constructing a NetworkVSphere resource.
        :param pulumi.Input[str] cidr: Network CIDR to be used.
        :param pulumi.Input[str] default_gateway: IPv4 default gateway to be used.
        :param pulumi.Input[str] default_ipv6_gateway: IPv6 default gateway to be used.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] dns_search_domains: List of dns search domains for the vSphere network.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] dns_server_addresses: A human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[str] domain: Domain for the vSphere network.
        :param pulumi.Input[str] ipv6_cidr: Network IPv6 CIDR to be used.
        :param pulumi.Input[bool] is_default: Indicates whether this is the default subnet for the zone.
        :param pulumi.Input[bool] is_public: Indicates whether the sub-network supports public IP assignment.
        :param pulumi.Input[Sequence[pulumi.Input['NetworkVSphereTagArgs']]] tags: Set of tag keys and values to apply to the resource.
               Example:[ { "key" : "vmware", "value": "provider" } ]
        """
        if cidr is not None:
            pulumi.set(__self__, "cidr", cidr)
        if default_gateway is not None:
            pulumi.set(__self__, "default_gateway", default_gateway)
        if default_ipv6_gateway is not None:
            pulumi.set(__self__, "default_ipv6_gateway", default_ipv6_gateway)
        if dns_search_domains is not None:
            pulumi.set(__self__, "dns_search_domains", dns_search_domains)
        if dns_server_addresses is not None:
            pulumi.set(__self__, "dns_server_addresses", dns_server_addresses)
        if domain is not None:
            pulumi.set(__self__, "domain", domain)
        if ipv6_cidr is not None:
            pulumi.set(__self__, "ipv6_cidr", ipv6_cidr)
        if is_default is not None:
            pulumi.set(__self__, "is_default", is_default)
        if is_public is not None:
            pulumi.set(__self__, "is_public", is_public)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter
    def cidr(self) -> Optional[pulumi.Input[str]]:
        """
        Network CIDR to be used.
        """
        return pulumi.get(self, "cidr")

    @cidr.setter
    def cidr(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cidr", value)

    @property
    @pulumi.getter(name="defaultGateway")
    def default_gateway(self) -> Optional[pulumi.Input[str]]:
        """
        IPv4 default gateway to be used.
        """
        return pulumi.get(self, "default_gateway")

    @default_gateway.setter
    def default_gateway(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "default_gateway", value)

    @property
    @pulumi.getter(name="defaultIpv6Gateway")
    def default_ipv6_gateway(self) -> Optional[pulumi.Input[str]]:
        """
        IPv6 default gateway to be used.
        """
        return pulumi.get(self, "default_ipv6_gateway")

    @default_ipv6_gateway.setter
    def default_ipv6_gateway(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "default_ipv6_gateway", value)

    @property
    @pulumi.getter(name="dnsSearchDomains")
    def dns_search_domains(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        List of dns search domains for the vSphere network.
        """
        return pulumi.get(self, "dns_search_domains")

    @dns_search_domains.setter
    def dns_search_domains(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "dns_search_domains", value)

    @property
    @pulumi.getter(name="dnsServerAddresses")
    def dns_server_addresses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "dns_server_addresses")

    @dns_server_addresses.setter
    def dns_server_addresses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "dns_server_addresses", value)

    @property
    @pulumi.getter
    def domain(self) -> Optional[pulumi.Input[str]]:
        """
        Domain for the vSphere network.
        """
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "domain", value)

    @property
    @pulumi.getter(name="ipv6Cidr")
    def ipv6_cidr(self) -> Optional[pulumi.Input[str]]:
        """
        Network IPv6 CIDR to be used.
        """
        return pulumi.get(self, "ipv6_cidr")

    @ipv6_cidr.setter
    def ipv6_cidr(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ipv6_cidr", value)

    @property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates whether this is the default subnet for the zone.
        """
        return pulumi.get(self, "is_default")

    @is_default.setter
    def is_default(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_default", value)

    @property
    @pulumi.getter(name="isPublic")
    def is_public(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates whether the sub-network supports public IP assignment.
        """
        return pulumi.get(self, "is_public")

    @is_public.setter
    def is_public(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_public", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NetworkVSphereTagArgs']]]]:
        """
        Set of tag keys and values to apply to the resource.
        Example:[ { "key" : "vmware", "value": "provider" } ]
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkVSphereTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _NetworkVSphereState:
    def __init__(__self__, *,
                 cidr: Optional[pulumi.Input[str]] = None,
                 cloud_account_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 created_at: Optional[pulumi.Input[str]] = None,
                 custom_properties: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 default_gateway: Optional[pulumi.Input[str]] = None,
                 default_ipv6_gateway: Optional[pulumi.Input[str]] = None,
                 dns_search_domains: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 dns_server_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 domain: Optional[pulumi.Input[str]] = None,
                 external_id: Optional[pulumi.Input[str]] = None,
                 external_region_id: Optional[pulumi.Input[str]] = None,
                 ipv6_cidr: Optional[pulumi.Input[str]] = None,
                 is_default: Optional[pulumi.Input[bool]] = None,
                 is_public: Optional[pulumi.Input[bool]] = None,
                 links: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkVSphereLinkArgs']]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 org_id: Optional[pulumi.Input[str]] = None,
                 organization_id: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkVSphereTagArgs']]]] = None,
                 updated_at: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering NetworkVSphere resources.
        :param pulumi.Input[str] cidr: Network CIDR to be used.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] cloud_account_ids: Set of ids of the cloud accounts this entity belongs to.
        :param pulumi.Input[str] created_at: Date when the entity was created. The date is in ISO 6801 and UTC.
        :param pulumi.Input[str] default_gateway: IPv4 default gateway to be used.
        :param pulumi.Input[str] default_ipv6_gateway: IPv6 default gateway to be used.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] dns_search_domains: List of dns search domains for the vSphere network.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] dns_server_addresses: A human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[str] domain: Domain for the vSphere network.
        :param pulumi.Input[str] external_id: External entity Id on the provider side.
        :param pulumi.Input[str] external_region_id: The id of the region for which this network is defined.
        :param pulumi.Input[str] ipv6_cidr: Network IPv6 CIDR to be used.
        :param pulumi.Input[bool] is_default: Indicates whether this is the default subnet for the zone.
        :param pulumi.Input[bool] is_public: Indicates whether the sub-network supports public IP assignment.
        :param pulumi.Input[Sequence[pulumi.Input['NetworkVSphereLinkArgs']]] links: HATEOAS of the entity
        :param pulumi.Input[str] name: A human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[str] organization_id: ID of organization that entity belongs to.
        :param pulumi.Input[Sequence[pulumi.Input['NetworkVSphereTagArgs']]] tags: Set of tag keys and values to apply to the resource.
               Example:[ { "key" : "vmware", "value": "provider" } ]
        :param pulumi.Input[str] updated_at: Date when the entity was last updated. The date is ISO 8601 and UTC.
        """
        if cidr is not None:
            pulumi.set(__self__, "cidr", cidr)
        if cloud_account_ids is not None:
            pulumi.set(__self__, "cloud_account_ids", cloud_account_ids)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if custom_properties is not None:
            pulumi.set(__self__, "custom_properties", custom_properties)
        if default_gateway is not None:
            pulumi.set(__self__, "default_gateway", default_gateway)
        if default_ipv6_gateway is not None:
            pulumi.set(__self__, "default_ipv6_gateway", default_ipv6_gateway)
        if dns_search_domains is not None:
            pulumi.set(__self__, "dns_search_domains", dns_search_domains)
        if dns_server_addresses is not None:
            pulumi.set(__self__, "dns_server_addresses", dns_server_addresses)
        if domain is not None:
            pulumi.set(__self__, "domain", domain)
        if external_id is not None:
            pulumi.set(__self__, "external_id", external_id)
        if external_region_id is not None:
            pulumi.set(__self__, "external_region_id", external_region_id)
        if ipv6_cidr is not None:
            pulumi.set(__self__, "ipv6_cidr", ipv6_cidr)
        if is_default is not None:
            pulumi.set(__self__, "is_default", is_default)
        if is_public is not None:
            pulumi.set(__self__, "is_public", is_public)
        if links is not None:
            pulumi.set(__self__, "links", links)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if organization_id is not None:
            pulumi.set(__self__, "organization_id", organization_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter
    def cidr(self) -> Optional[pulumi.Input[str]]:
        """
        Network CIDR to be used.
        """
        return pulumi.get(self, "cidr")

    @cidr.setter
    def cidr(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cidr", value)

    @property
    @pulumi.getter(name="cloudAccountIds")
    def cloud_account_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Set of ids of the cloud accounts this entity belongs to.
        """
        return pulumi.get(self, "cloud_account_ids")

    @cloud_account_ids.setter
    def cloud_account_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "cloud_account_ids", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[str]]:
        """
        Date when the entity was created. The date is in ISO 6801 and UTC.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter(name="customProperties")
    def custom_properties(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        return pulumi.get(self, "custom_properties")

    @custom_properties.setter
    def custom_properties(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "custom_properties", value)

    @property
    @pulumi.getter(name="defaultGateway")
    def default_gateway(self) -> Optional[pulumi.Input[str]]:
        """
        IPv4 default gateway to be used.
        """
        return pulumi.get(self, "default_gateway")

    @default_gateway.setter
    def default_gateway(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "default_gateway", value)

    @property
    @pulumi.getter(name="defaultIpv6Gateway")
    def default_ipv6_gateway(self) -> Optional[pulumi.Input[str]]:
        """
        IPv6 default gateway to be used.
        """
        return pulumi.get(self, "default_ipv6_gateway")

    @default_ipv6_gateway.setter
    def default_ipv6_gateway(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "default_ipv6_gateway", value)

    @property
    @pulumi.getter(name="dnsSearchDomains")
    def dns_search_domains(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        List of dns search domains for the vSphere network.
        """
        return pulumi.get(self, "dns_search_domains")

    @dns_search_domains.setter
    def dns_search_domains(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "dns_search_domains", value)

    @property
    @pulumi.getter(name="dnsServerAddresses")
    def dns_server_addresses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "dns_server_addresses")

    @dns_server_addresses.setter
    def dns_server_addresses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "dns_server_addresses", value)

    @property
    @pulumi.getter
    def domain(self) -> Optional[pulumi.Input[str]]:
        """
        Domain for the vSphere network.
        """
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "domain", value)

    @property
    @pulumi.getter(name="externalId")
    def external_id(self) -> Optional[pulumi.Input[str]]:
        """
        External entity Id on the provider side.
        """
        return pulumi.get(self, "external_id")

    @external_id.setter
    def external_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "external_id", value)

    @property
    @pulumi.getter(name="externalRegionId")
    def external_region_id(self) -> Optional[pulumi.Input[str]]:
        """
        The id of the region for which this network is defined.
        """
        return pulumi.get(self, "external_region_id")

    @external_region_id.setter
    def external_region_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "external_region_id", value)

    @property
    @pulumi.getter(name="ipv6Cidr")
    def ipv6_cidr(self) -> Optional[pulumi.Input[str]]:
        """
        Network IPv6 CIDR to be used.
        """
        return pulumi.get(self, "ipv6_cidr")

    @ipv6_cidr.setter
    def ipv6_cidr(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ipv6_cidr", value)

    @property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates whether this is the default subnet for the zone.
        """
        return pulumi.get(self, "is_default")

    @is_default.setter
    def is_default(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_default", value)

    @property
    @pulumi.getter(name="isPublic")
    def is_public(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates whether the sub-network supports public IP assignment.
        """
        return pulumi.get(self, "is_public")

    @is_public.setter
    def is_public(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_public", value)

    @property
    @pulumi.getter
    def links(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NetworkVSphereLinkArgs']]]]:
        """
        HATEOAS of the entity
        """
        return pulumi.get(self, "links")

    @links.setter
    def links(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkVSphereLinkArgs']]]]):
        pulumi.set(self, "links", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        A human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "org_id", value)

    @property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of organization that entity belongs to.
        """
        return pulumi.get(self, "organization_id")

    @organization_id.setter
    def organization_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "organization_id", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NetworkVSphereTagArgs']]]]:
        """
        Set of tag keys and values to apply to the resource.
        Example:[ { "key" : "vmware", "value": "provider" } ]
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkVSphereTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[str]]:
        """
        Date when the entity was last updated. The date is ISO 8601 and UTC.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "updated_at", value)


class NetworkVSphere(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cidr: Optional[pulumi.Input[str]] = None,
                 default_gateway: Optional[pulumi.Input[str]] = None,
                 default_ipv6_gateway: Optional[pulumi.Input[str]] = None,
                 dns_search_domains: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 dns_server_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 domain: Optional[pulumi.Input[str]] = None,
                 ipv6_cidr: Optional[pulumi.Input[str]] = None,
                 is_default: Optional[pulumi.Input[bool]] = None,
                 is_public: Optional[pulumi.Input[bool]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['NetworkVSphereTagArgs']]]]] = None,
                 __props__=None):
        """
        Updates a VMware vRealize Automation fabric_network_vsphere resource.

        ## Example Usage
        ### S

        You cannot create a vSphere fabric network resource, however you can import using the command specified in the import section below.
        Once a resource is imported, you can update it as shown below:

        ```python
        import pulumi
        import pulumiverse_vra as vra

        simple = vra.fabric.NetworkVSphere("simple",
            cidr=var["cidr"],
            default_gateway=var["gateway"],
            domain=var["domain"],
            tags=[vra.fabric.NetworkVSphereTagArgs(
                key="foo",
                value="bar",
            )])
        ```

        ## Import

        To import the vSphere fabric network resource, use the ID as in the following example

        ```sh
         $ pulumi import vra:fabric/networkVSphere:NetworkVSphere new_fabric_network_vsphere 05956583-6488-4e7d-84c9-92a7b7219a15`
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] cidr: Network CIDR to be used.
        :param pulumi.Input[str] default_gateway: IPv4 default gateway to be used.
        :param pulumi.Input[str] default_ipv6_gateway: IPv6 default gateway to be used.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] dns_search_domains: List of dns search domains for the vSphere network.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] dns_server_addresses: A human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[str] domain: Domain for the vSphere network.
        :param pulumi.Input[str] ipv6_cidr: Network IPv6 CIDR to be used.
        :param pulumi.Input[bool] is_default: Indicates whether this is the default subnet for the zone.
        :param pulumi.Input[bool] is_public: Indicates whether the sub-network supports public IP assignment.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['NetworkVSphereTagArgs']]]] tags: Set of tag keys and values to apply to the resource.
               Example:[ { "key" : "vmware", "value": "provider" } ]
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[NetworkVSphereArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Updates a VMware vRealize Automation fabric_network_vsphere resource.

        ## Example Usage
        ### S

        You cannot create a vSphere fabric network resource, however you can import using the command specified in the import section below.
        Once a resource is imported, you can update it as shown below:

        ```python
        import pulumi
        import pulumiverse_vra as vra

        simple = vra.fabric.NetworkVSphere("simple",
            cidr=var["cidr"],
            default_gateway=var["gateway"],
            domain=var["domain"],
            tags=[vra.fabric.NetworkVSphereTagArgs(
                key="foo",
                value="bar",
            )])
        ```

        ## Import

        To import the vSphere fabric network resource, use the ID as in the following example

        ```sh
         $ pulumi import vra:fabric/networkVSphere:NetworkVSphere new_fabric_network_vsphere 05956583-6488-4e7d-84c9-92a7b7219a15`
        ```

        :param str resource_name: The name of the resource.
        :param NetworkVSphereArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NetworkVSphereArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cidr: Optional[pulumi.Input[str]] = None,
                 default_gateway: Optional[pulumi.Input[str]] = None,
                 default_ipv6_gateway: Optional[pulumi.Input[str]] = None,
                 dns_search_domains: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 dns_server_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 domain: Optional[pulumi.Input[str]] = None,
                 ipv6_cidr: Optional[pulumi.Input[str]] = None,
                 is_default: Optional[pulumi.Input[bool]] = None,
                 is_public: Optional[pulumi.Input[bool]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['NetworkVSphereTagArgs']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NetworkVSphereArgs.__new__(NetworkVSphereArgs)

            __props__.__dict__["cidr"] = cidr
            __props__.__dict__["default_gateway"] = default_gateway
            __props__.__dict__["default_ipv6_gateway"] = default_ipv6_gateway
            __props__.__dict__["dns_search_domains"] = dns_search_domains
            __props__.__dict__["dns_server_addresses"] = dns_server_addresses
            __props__.__dict__["domain"] = domain
            __props__.__dict__["ipv6_cidr"] = ipv6_cidr
            __props__.__dict__["is_default"] = is_default
            __props__.__dict__["is_public"] = is_public
            __props__.__dict__["tags"] = tags
            __props__.__dict__["cloud_account_ids"] = None
            __props__.__dict__["created_at"] = None
            __props__.__dict__["custom_properties"] = None
            __props__.__dict__["external_id"] = None
            __props__.__dict__["external_region_id"] = None
            __props__.__dict__["links"] = None
            __props__.__dict__["name"] = None
            __props__.__dict__["org_id"] = None
            __props__.__dict__["organization_id"] = None
            __props__.__dict__["updated_at"] = None
        super(NetworkVSphere, __self__).__init__(
            'vra:fabric/networkVSphere:NetworkVSphere',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cidr: Optional[pulumi.Input[str]] = None,
            cloud_account_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            created_at: Optional[pulumi.Input[str]] = None,
            custom_properties: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            default_gateway: Optional[pulumi.Input[str]] = None,
            default_ipv6_gateway: Optional[pulumi.Input[str]] = None,
            dns_search_domains: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            dns_server_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            domain: Optional[pulumi.Input[str]] = None,
            external_id: Optional[pulumi.Input[str]] = None,
            external_region_id: Optional[pulumi.Input[str]] = None,
            ipv6_cidr: Optional[pulumi.Input[str]] = None,
            is_default: Optional[pulumi.Input[bool]] = None,
            is_public: Optional[pulumi.Input[bool]] = None,
            links: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['NetworkVSphereLinkArgs']]]]] = None,
            name: Optional[pulumi.Input[str]] = None,
            org_id: Optional[pulumi.Input[str]] = None,
            organization_id: Optional[pulumi.Input[str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['NetworkVSphereTagArgs']]]]] = None,
            updated_at: Optional[pulumi.Input[str]] = None) -> 'NetworkVSphere':
        """
        Get an existing NetworkVSphere resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] cidr: Network CIDR to be used.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] cloud_account_ids: Set of ids of the cloud accounts this entity belongs to.
        :param pulumi.Input[str] created_at: Date when the entity was created. The date is in ISO 6801 and UTC.
        :param pulumi.Input[str] default_gateway: IPv4 default gateway to be used.
        :param pulumi.Input[str] default_ipv6_gateway: IPv6 default gateway to be used.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] dns_search_domains: List of dns search domains for the vSphere network.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] dns_server_addresses: A human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[str] domain: Domain for the vSphere network.
        :param pulumi.Input[str] external_id: External entity Id on the provider side.
        :param pulumi.Input[str] external_region_id: The id of the region for which this network is defined.
        :param pulumi.Input[str] ipv6_cidr: Network IPv6 CIDR to be used.
        :param pulumi.Input[bool] is_default: Indicates whether this is the default subnet for the zone.
        :param pulumi.Input[bool] is_public: Indicates whether the sub-network supports public IP assignment.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['NetworkVSphereLinkArgs']]]] links: HATEOAS of the entity
        :param pulumi.Input[str] name: A human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[str] organization_id: ID of organization that entity belongs to.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['NetworkVSphereTagArgs']]]] tags: Set of tag keys and values to apply to the resource.
               Example:[ { "key" : "vmware", "value": "provider" } ]
        :param pulumi.Input[str] updated_at: Date when the entity was last updated. The date is ISO 8601 and UTC.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NetworkVSphereState.__new__(_NetworkVSphereState)

        __props__.__dict__["cidr"] = cidr
        __props__.__dict__["cloud_account_ids"] = cloud_account_ids
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["custom_properties"] = custom_properties
        __props__.__dict__["default_gateway"] = default_gateway
        __props__.__dict__["default_ipv6_gateway"] = default_ipv6_gateway
        __props__.__dict__["dns_search_domains"] = dns_search_domains
        __props__.__dict__["dns_server_addresses"] = dns_server_addresses
        __props__.__dict__["domain"] = domain
        __props__.__dict__["external_id"] = external_id
        __props__.__dict__["external_region_id"] = external_region_id
        __props__.__dict__["ipv6_cidr"] = ipv6_cidr
        __props__.__dict__["is_default"] = is_default
        __props__.__dict__["is_public"] = is_public
        __props__.__dict__["links"] = links
        __props__.__dict__["name"] = name
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["organization_id"] = organization_id
        __props__.__dict__["tags"] = tags
        __props__.__dict__["updated_at"] = updated_at
        return NetworkVSphere(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def cidr(self) -> pulumi.Output[str]:
        """
        Network CIDR to be used.
        """
        return pulumi.get(self, "cidr")

    @property
    @pulumi.getter(name="cloudAccountIds")
    def cloud_account_ids(self) -> pulumi.Output[Sequence[str]]:
        """
        Set of ids of the cloud accounts this entity belongs to.
        """
        return pulumi.get(self, "cloud_account_ids")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[str]:
        """
        Date when the entity was created. The date is in ISO 6801 and UTC.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="customProperties")
    def custom_properties(self) -> pulumi.Output[Mapping[str, Any]]:
        return pulumi.get(self, "custom_properties")

    @property
    @pulumi.getter(name="defaultGateway")
    def default_gateway(self) -> pulumi.Output[str]:
        """
        IPv4 default gateway to be used.
        """
        return pulumi.get(self, "default_gateway")

    @property
    @pulumi.getter(name="defaultIpv6Gateway")
    def default_ipv6_gateway(self) -> pulumi.Output[str]:
        """
        IPv6 default gateway to be used.
        """
        return pulumi.get(self, "default_ipv6_gateway")

    @property
    @pulumi.getter(name="dnsSearchDomains")
    def dns_search_domains(self) -> pulumi.Output[Sequence[str]]:
        """
        List of dns search domains for the vSphere network.
        """
        return pulumi.get(self, "dns_search_domains")

    @property
    @pulumi.getter(name="dnsServerAddresses")
    def dns_server_addresses(self) -> pulumi.Output[Sequence[str]]:
        """
        A human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "dns_server_addresses")

    @property
    @pulumi.getter
    def domain(self) -> pulumi.Output[Optional[str]]:
        """
        Domain for the vSphere network.
        """
        return pulumi.get(self, "domain")

    @property
    @pulumi.getter(name="externalId")
    def external_id(self) -> pulumi.Output[str]:
        """
        External entity Id on the provider side.
        """
        return pulumi.get(self, "external_id")

    @property
    @pulumi.getter(name="externalRegionId")
    def external_region_id(self) -> pulumi.Output[str]:
        """
        The id of the region for which this network is defined.
        """
        return pulumi.get(self, "external_region_id")

    @property
    @pulumi.getter(name="ipv6Cidr")
    def ipv6_cidr(self) -> pulumi.Output[Optional[str]]:
        """
        Network IPv6 CIDR to be used.
        """
        return pulumi.get(self, "ipv6_cidr")

    @property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> pulumi.Output[Optional[bool]]:
        """
        Indicates whether this is the default subnet for the zone.
        """
        return pulumi.get(self, "is_default")

    @property
    @pulumi.getter(name="isPublic")
    def is_public(self) -> pulumi.Output[Optional[bool]]:
        """
        Indicates whether the sub-network supports public IP assignment.
        """
        return pulumi.get(self, "is_public")

    @property
    @pulumi.getter
    def links(self) -> pulumi.Output[Sequence['outputs.NetworkVSphereLink']]:
        """
        HATEOAS of the entity
        """
        return pulumi.get(self, "links")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        A human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[str]:
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> pulumi.Output[str]:
        """
        ID of organization that entity belongs to.
        """
        return pulumi.get(self, "organization_id")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.NetworkVSphereTag']]:
        """
        Set of tag keys and values to apply to the resource.
        Example:[ { "key" : "vmware", "value": "provider" } ]
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[str]:
        """
        Date when the entity was last updated. The date is ISO 8601 and UTC.
        """
        return pulumi.get(self, "updated_at")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'ProfileFlavorMappingArgs',
    'ProfileLinkArgs',
]

@pulumi.input_type
class ProfileFlavorMappingArgs:
    def __init__(__self__, *,
                 name: pulumi.Input[str],
                 cpu_count: Optional[pulumi.Input[int]] = None,
                 instance_type: Optional[pulumi.Input[str]] = None,
                 memory: Optional[pulumi.Input[int]] = None):
        """
        :param pulumi.Input[str] name: A human-friendly name used as an identifier in APIs that support this option.
        """
        pulumi.set(__self__, "name", name)
        if cpu_count is not None:
            pulumi.set(__self__, "cpu_count", cpu_count)
        if instance_type is not None:
            pulumi.set(__self__, "instance_type", instance_type)
        if memory is not None:
            pulumi.set(__self__, "memory", memory)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        """
        A human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="cpuCount")
    def cpu_count(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "cpu_count")

    @cpu_count.setter
    def cpu_count(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "cpu_count", value)

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "instance_type")

    @instance_type.setter
    def instance_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_type", value)

    @property
    @pulumi.getter
    def memory(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "memory")

    @memory.setter
    def memory(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "memory", value)


@pulumi.input_type
class ProfileLinkArgs:
    def __init__(__self__, *,
                 rel: pulumi.Input[str],
                 href: Optional[pulumi.Input[str]] = None,
                 hrefs: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> pulumi.Input[str]:
        return pulumi.get(self, "rel")

    @rel.setter
    def rel(self, value: pulumi.Input[str]):
        pulumi.set(self, "rel", value)

    @property
    @pulumi.getter
    def href(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "href")

    @href.setter
    def href(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "href", value)

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "hrefs")

    @hrefs.setter
    def hrefs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "hrefs", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DeploymentArgs', 'Deployment']

@pulumi.input_type
class DeploymentArgs:
    def __init__(__self__, *,
                 project_id: pulumi.Input[str],
                 blueprint_content: Optional[pulumi.Input[str]] = None,
                 blueprint_id: Optional[pulumi.Input[str]] = None,
                 blueprint_version: Optional[pulumi.Input[str]] = None,
                 catalog_item_id: Optional[pulumi.Input[str]] = None,
                 catalog_item_version: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 expand_last_request: Optional[pulumi.Input[bool]] = None,
                 expand_project: Optional[pulumi.Input[bool]] = None,
                 expand_resources: Optional[pulumi.Input[bool]] = None,
                 inputs: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 lease_expire_at: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 owner: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Deployment resource.
        :param pulumi.Input[str] project_id: The id of the project this entity belongs to.
        :param pulumi.Input[str] blueprint_content: vRA Cloud template content. Conflicts with `blueprint_id` and `catalog_item_id`.
        :param pulumi.Input[str] blueprint_id: Identifier of the requested blueprint in the form ‘UUID:version’.
        :param pulumi.Input[str] blueprint_version: The version of the vRA cloud template to request the deployment. Used only when `blueprint_id` is provided.
        :param pulumi.Input[str] catalog_item_id: The id of the vRA catalog item to request the deployment. Conflicts with `blueprint_id` and `blueprint_content`.
        :param pulumi.Input[str] catalog_item_version: The version of the vRA catalog item to request the deployment. Used only when `catalog_item_id` is provided.
        :param pulumi.Input[str] description: A human-friendly description.
        :param pulumi.Input[bool] expand_project: Flag to indicate whether to expand project information.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] inputs: Inputs provided by the user. For inputs including those with default values, refer to `inputs_including_defaults`.
        :param pulumi.Input[str] lease_expire_at: Time at which the deployment lease expires.
        :param pulumi.Input[str] name: A human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[str] owner: The user this deployment belongs to. At create, the owner is ignored but is used to update during next apply.
        """
        pulumi.set(__self__, "project_id", project_id)
        if blueprint_content is not None:
            pulumi.set(__self__, "blueprint_content", blueprint_content)
        if blueprint_id is not None:
            pulumi.set(__self__, "blueprint_id", blueprint_id)
        if blueprint_version is not None:
            pulumi.set(__self__, "blueprint_version", blueprint_version)
        if catalog_item_id is not None:
            pulumi.set(__self__, "catalog_item_id", catalog_item_id)
        if catalog_item_version is not None:
            pulumi.set(__self__, "catalog_item_version", catalog_item_version)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if expand_last_request is not None:
            warnings.warn("""Deprecated. True by default even if not provided.""", DeprecationWarning)
            pulumi.log.warn("""expand_last_request is deprecated: Deprecated. True by default even if not provided.""")
        if expand_last_request is not None:
            pulumi.set(__self__, "expand_last_request", expand_last_request)
        if expand_project is not None:
            pulumi.set(__self__, "expand_project", expand_project)
        if expand_resources is not None:
            warnings.warn("""Deprecated. True by default even if not provided.""", DeprecationWarning)
            pulumi.log.warn("""expand_resources is deprecated: Deprecated. True by default even if not provided.""")
        if expand_resources is not None:
            pulumi.set(__self__, "expand_resources", expand_resources)
        if inputs is not None:
            pulumi.set(__self__, "inputs", inputs)
        if lease_expire_at is not None:
            pulumi.set(__self__, "lease_expire_at", lease_expire_at)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if owner is not None:
            pulumi.set(__self__, "owner", owner)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[str]:
        """
        The id of the project this entity belongs to.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter(name="blueprintContent")
    def blueprint_content(self) -> Optional[pulumi.Input[str]]:
        """
        vRA Cloud template content. Conflicts with `blueprint_id` and `catalog_item_id`.
        """
        return pulumi.get(self, "blueprint_content")

    @blueprint_content.setter
    def blueprint_content(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "blueprint_content", value)

    @property
    @pulumi.getter(name="blueprintId")
    def blueprint_id(self) -> Optional[pulumi.Input[str]]:
        """
        Identifier of the requested blueprint in the form ‘UUID:version’.
        """
        return pulumi.get(self, "blueprint_id")

    @blueprint_id.setter
    def blueprint_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "blueprint_id", value)

    @property
    @pulumi.getter(name="blueprintVersion")
    def blueprint_version(self) -> Optional[pulumi.Input[str]]:
        """
        The version of the vRA cloud template to request the deployment. Used only when `blueprint_id` is provided.
        """
        return pulumi.get(self, "blueprint_version")

    @blueprint_version.setter
    def blueprint_version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "blueprint_version", value)

    @property
    @pulumi.getter(name="catalogItemId")
    def catalog_item_id(self) -> Optional[pulumi.Input[str]]:
        """
        The id of the vRA catalog item to request the deployment. Conflicts with `blueprint_id` and `blueprint_content`.
        """
        return pulumi.get(self, "catalog_item_id")

    @catalog_item_id.setter
    def catalog_item_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "catalog_item_id", value)

    @property
    @pulumi.getter(name="catalogItemVersion")
    def catalog_item_version(self) -> Optional[pulumi.Input[str]]:
        """
        The version of the vRA catalog item to request the deployment. Used only when `catalog_item_id` is provided.
        """
        return pulumi.get(self, "catalog_item_version")

    @catalog_item_version.setter
    def catalog_item_version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "catalog_item_version", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        A human-friendly description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="expandLastRequest")
    def expand_last_request(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "expand_last_request")

    @expand_last_request.setter
    def expand_last_request(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "expand_last_request", value)

    @property
    @pulumi.getter(name="expandProject")
    def expand_project(self) -> Optional[pulumi.Input[bool]]:
        """
        Flag to indicate whether to expand project information.
        """
        return pulumi.get(self, "expand_project")

    @expand_project.setter
    def expand_project(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "expand_project", value)

    @property
    @pulumi.getter(name="expandResources")
    def expand_resources(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "expand_resources")

    @expand_resources.setter
    def expand_resources(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "expand_resources", value)

    @property
    @pulumi.getter
    def inputs(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Inputs provided by the user. For inputs including those with default values, refer to `inputs_including_defaults`.
        """
        return pulumi.get(self, "inputs")

    @inputs.setter
    def inputs(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "inputs", value)

    @property
    @pulumi.getter(name="leaseExpireAt")
    def lease_expire_at(self) -> Optional[pulumi.Input[str]]:
        """
        Time at which the deployment lease expires.
        """
        return pulumi.get(self, "lease_expire_at")

    @lease_expire_at.setter
    def lease_expire_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "lease_expire_at", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        A human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def owner(self) -> Optional[pulumi.Input[str]]:
        """
        The user this deployment belongs to. At create, the owner is ignored but is used to update during next apply.
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "owner", value)


@pulumi.input_type
class _DeploymentState:
    def __init__(__self__, *,
                 blueprint_content: Optional[pulumi.Input[str]] = None,
                 blueprint_id: Optional[pulumi.Input[str]] = None,
                 blueprint_version: Optional[pulumi.Input[str]] = None,
                 catalog_item_id: Optional[pulumi.Input[str]] = None,
                 catalog_item_version: Optional[pulumi.Input[str]] = None,
                 created_at: Optional[pulumi.Input[str]] = None,
                 created_by: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 expand_last_request: Optional[pulumi.Input[bool]] = None,
                 expand_project: Optional[pulumi.Input[bool]] = None,
                 expand_resources: Optional[pulumi.Input[bool]] = None,
                 expenses: Optional[pulumi.Input[Sequence[pulumi.Input['DeploymentExpenseArgs']]]] = None,
                 inputs: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 inputs_including_defaults: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 last_requests: Optional[pulumi.Input[Sequence[pulumi.Input['DeploymentLastRequestArgs']]]] = None,
                 last_updated_at: Optional[pulumi.Input[str]] = None,
                 last_updated_by: Optional[pulumi.Input[str]] = None,
                 lease_expire_at: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 org_id: Optional[pulumi.Input[str]] = None,
                 owner: Optional[pulumi.Input[str]] = None,
                 project_id: Optional[pulumi.Input[str]] = None,
                 projects: Optional[pulumi.Input[Sequence[pulumi.Input['DeploymentProjectArgs']]]] = None,
                 resources: Optional[pulumi.Input[Sequence[pulumi.Input['DeploymentResourceArgs']]]] = None,
                 status: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Deployment resources.
        :param pulumi.Input[str] blueprint_content: vRA Cloud template content. Conflicts with `blueprint_id` and `catalog_item_id`.
        :param pulumi.Input[str] blueprint_id: Identifier of the requested blueprint in the form ‘UUID:version’.
        :param pulumi.Input[str] blueprint_version: The version of the vRA cloud template to request the deployment. Used only when `blueprint_id` is provided.
        :param pulumi.Input[str] catalog_item_id: The id of the vRA catalog item to request the deployment. Conflicts with `blueprint_id` and `blueprint_content`.
        :param pulumi.Input[str] catalog_item_version: The version of the vRA catalog item to request the deployment. Used only when `catalog_item_id` is provided.
        :param pulumi.Input[str] created_at: Creation time (e.g. date format ‘2019-07-13T23:16:49.310Z’).
        :param pulumi.Input[str] created_by: The user the entity was created by.
        :param pulumi.Input[str] description: A human-friendly description.
        :param pulumi.Input[bool] expand_project: Flag to indicate whether to expand project information.
        :param pulumi.Input[Sequence[pulumi.Input['DeploymentExpenseArgs']]] expenses: Expense incurred for the deployment.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] inputs: Inputs provided by the user. For inputs including those with default values, refer to `inputs_including_defaults`.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] inputs_including_defaults: All the inputs applied during last create/update operation, including those with default values. For the list of inputs provided by the user in the configuration, refer to `inputs`.
        :param pulumi.Input[Sequence[pulumi.Input['DeploymentLastRequestArgs']]] last_requests: Represents deployment requests.
        :param pulumi.Input[str] last_updated_at: Time at which the deployment was last updated.
        :param pulumi.Input[str] last_updated_by: The user that last updated the deployment.
        :param pulumi.Input[str] lease_expire_at: Time at which the deployment lease expires.
        :param pulumi.Input[str] name: A human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[str] org_id: The ID of the organization this deployment belongs to.
        :param pulumi.Input[str] owner: The user this deployment belongs to. At create, the owner is ignored but is used to update during next apply.
        :param pulumi.Input[str] project_id: The id of the project this entity belongs to.
        :param pulumi.Input[Sequence[pulumi.Input['DeploymentProjectArgs']]] projects: The project this entity belongs to.
        :param pulumi.Input[Sequence[pulumi.Input['DeploymentResourceArgs']]] resources: Expanded resources for the deployment. Content of this property will not be maintained backward compatible.
        :param pulumi.Input[str] status: Deployment status. Supported values are: `CREATE_SUCCESSFUL`, `CREATE_INPROGRESS`, `CREATE_FAILED`, `UPDATE_SUCCESSFUL`, `UPDATE_INPROGRESS`, `UPDATE_FAILED`, `DELETE_SUCCESSFUL`, `DELETE_INPROGRESS`, `DELETE_FAILED`, `ACTION_SUCCESSFUL`, `ACTION_INPROGRESS`, `ACTION_FAILED`.
        """
        if blueprint_content is not None:
            pulumi.set(__self__, "blueprint_content", blueprint_content)
        if blueprint_id is not None:
            pulumi.set(__self__, "blueprint_id", blueprint_id)
        if blueprint_version is not None:
            pulumi.set(__self__, "blueprint_version", blueprint_version)
        if catalog_item_id is not None:
            pulumi.set(__self__, "catalog_item_id", catalog_item_id)
        if catalog_item_version is not None:
            pulumi.set(__self__, "catalog_item_version", catalog_item_version)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if created_by is not None:
            pulumi.set(__self__, "created_by", created_by)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if expand_last_request is not None:
            warnings.warn("""Deprecated. True by default even if not provided.""", DeprecationWarning)
            pulumi.log.warn("""expand_last_request is deprecated: Deprecated. True by default even if not provided.""")
        if expand_last_request is not None:
            pulumi.set(__self__, "expand_last_request", expand_last_request)
        if expand_project is not None:
            pulumi.set(__self__, "expand_project", expand_project)
        if expand_resources is not None:
            warnings.warn("""Deprecated. True by default even if not provided.""", DeprecationWarning)
            pulumi.log.warn("""expand_resources is deprecated: Deprecated. True by default even if not provided.""")
        if expand_resources is not None:
            pulumi.set(__self__, "expand_resources", expand_resources)
        if expenses is not None:
            pulumi.set(__self__, "expenses", expenses)
        if inputs is not None:
            pulumi.set(__self__, "inputs", inputs)
        if inputs_including_defaults is not None:
            pulumi.set(__self__, "inputs_including_defaults", inputs_including_defaults)
        if last_requests is not None:
            pulumi.set(__self__, "last_requests", last_requests)
        if last_updated_at is not None:
            pulumi.set(__self__, "last_updated_at", last_updated_at)
        if last_updated_by is not None:
            pulumi.set(__self__, "last_updated_by", last_updated_by)
        if lease_expire_at is not None:
            pulumi.set(__self__, "lease_expire_at", lease_expire_at)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if owner is not None:
            pulumi.set(__self__, "owner", owner)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if projects is not None:
            pulumi.set(__self__, "projects", projects)
        if resources is not None:
            pulumi.set(__self__, "resources", resources)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="blueprintContent")
    def blueprint_content(self) -> Optional[pulumi.Input[str]]:
        """
        vRA Cloud template content. Conflicts with `blueprint_id` and `catalog_item_id`.
        """
        return pulumi.get(self, "blueprint_content")

    @blueprint_content.setter
    def blueprint_content(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "blueprint_content", value)

    @property
    @pulumi.getter(name="blueprintId")
    def blueprint_id(self) -> Optional[pulumi.Input[str]]:
        """
        Identifier of the requested blueprint in the form ‘UUID:version’.
        """
        return pulumi.get(self, "blueprint_id")

    @blueprint_id.setter
    def blueprint_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "blueprint_id", value)

    @property
    @pulumi.getter(name="blueprintVersion")
    def blueprint_version(self) -> Optional[pulumi.Input[str]]:
        """
        The version of the vRA cloud template to request the deployment. Used only when `blueprint_id` is provided.
        """
        return pulumi.get(self, "blueprint_version")

    @blueprint_version.setter
    def blueprint_version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "blueprint_version", value)

    @property
    @pulumi.getter(name="catalogItemId")
    def catalog_item_id(self) -> Optional[pulumi.Input[str]]:
        """
        The id of the vRA catalog item to request the deployment. Conflicts with `blueprint_id` and `blueprint_content`.
        """
        return pulumi.get(self, "catalog_item_id")

    @catalog_item_id.setter
    def catalog_item_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "catalog_item_id", value)

    @property
    @pulumi.getter(name="catalogItemVersion")
    def catalog_item_version(self) -> Optional[pulumi.Input[str]]:
        """
        The version of the vRA catalog item to request the deployment. Used only when `catalog_item_id` is provided.
        """
        return pulumi.get(self, "catalog_item_version")

    @catalog_item_version.setter
    def catalog_item_version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "catalog_item_version", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[str]]:
        """
        Creation time (e.g. date format ‘2019-07-13T23:16:49.310Z’).
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> Optional[pulumi.Input[str]]:
        """
        The user the entity was created by.
        """
        return pulumi.get(self, "created_by")

    @created_by.setter
    def created_by(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_by", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        A human-friendly description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="expandLastRequest")
    def expand_last_request(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "expand_last_request")

    @expand_last_request.setter
    def expand_last_request(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "expand_last_request", value)

    @property
    @pulumi.getter(name="expandProject")
    def expand_project(self) -> Optional[pulumi.Input[bool]]:
        """
        Flag to indicate whether to expand project information.
        """
        return pulumi.get(self, "expand_project")

    @expand_project.setter
    def expand_project(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "expand_project", value)

    @property
    @pulumi.getter(name="expandResources")
    def expand_resources(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "expand_resources")

    @expand_resources.setter
    def expand_resources(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "expand_resources", value)

    @property
    @pulumi.getter
    def expenses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DeploymentExpenseArgs']]]]:
        """
        Expense incurred for the deployment.
        """
        return pulumi.get(self, "expenses")

    @expenses.setter
    def expenses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DeploymentExpenseArgs']]]]):
        pulumi.set(self, "expenses", value)

    @property
    @pulumi.getter
    def inputs(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Inputs provided by the user. For inputs including those with default values, refer to `inputs_including_defaults`.
        """
        return pulumi.get(self, "inputs")

    @inputs.setter
    def inputs(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "inputs", value)

    @property
    @pulumi.getter(name="inputsIncludingDefaults")
    def inputs_including_defaults(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        All the inputs applied during last create/update operation, including those with default values. For the list of inputs provided by the user in the configuration, refer to `inputs`.
        """
        return pulumi.get(self, "inputs_including_defaults")

    @inputs_including_defaults.setter
    def inputs_including_defaults(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "inputs_including_defaults", value)

    @property
    @pulumi.getter(name="lastRequests")
    def last_requests(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DeploymentLastRequestArgs']]]]:
        """
        Represents deployment requests.
        """
        return pulumi.get(self, "last_requests")

    @last_requests.setter
    def last_requests(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DeploymentLastRequestArgs']]]]):
        pulumi.set(self, "last_requests", value)

    @property
    @pulumi.getter(name="lastUpdatedAt")
    def last_updated_at(self) -> Optional[pulumi.Input[str]]:
        """
        Time at which the deployment was last updated.
        """
        return pulumi.get(self, "last_updated_at")

    @last_updated_at.setter
    def last_updated_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "last_updated_at", value)

    @property
    @pulumi.getter(name="lastUpdatedBy")
    def last_updated_by(self) -> Optional[pulumi.Input[str]]:
        """
        The user that last updated the deployment.
        """
        return pulumi.get(self, "last_updated_by")

    @last_updated_by.setter
    def last_updated_by(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "last_updated_by", value)

    @property
    @pulumi.getter(name="leaseExpireAt")
    def lease_expire_at(self) -> Optional[pulumi.Input[str]]:
        """
        Time at which the deployment lease expires.
        """
        return pulumi.get(self, "lease_expire_at")

    @lease_expire_at.setter
    def lease_expire_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "lease_expire_at", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        A human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the organization this deployment belongs to.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "org_id", value)

    @property
    @pulumi.getter
    def owner(self) -> Optional[pulumi.Input[str]]:
        """
        The user this deployment belongs to. At create, the owner is ignored but is used to update during next apply.
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "owner", value)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[str]]:
        """
        The id of the project this entity belongs to.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter
    def projects(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DeploymentProjectArgs']]]]:
        """
        The project this entity belongs to.
        """
        return pulumi.get(self, "projects")

    @projects.setter
    def projects(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DeploymentProjectArgs']]]]):
        pulumi.set(self, "projects", value)

    @property
    @pulumi.getter
    def resources(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DeploymentResourceArgs']]]]:
        """
        Expanded resources for the deployment. Content of this property will not be maintained backward compatible.
        """
        return pulumi.get(self, "resources")

    @resources.setter
    def resources(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DeploymentResourceArgs']]]]):
        pulumi.set(self, "resources", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        Deployment status. Supported values are: `CREATE_SUCCESSFUL`, `CREATE_INPROGRESS`, `CREATE_FAILED`, `UPDATE_SUCCESSFUL`, `UPDATE_INPROGRESS`, `UPDATE_FAILED`, `DELETE_SUCCESSFUL`, `DELETE_INPROGRESS`, `DELETE_FAILED`, `ACTION_SUCCESSFUL`, `ACTION_INPROGRESS`, `ACTION_FAILED`.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


class Deployment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 blueprint_content: Optional[pulumi.Input[str]] = None,
                 blueprint_id: Optional[pulumi.Input[str]] = None,
                 blueprint_version: Optional[pulumi.Input[str]] = None,
                 catalog_item_id: Optional[pulumi.Input[str]] = None,
                 catalog_item_version: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 expand_last_request: Optional[pulumi.Input[bool]] = None,
                 expand_project: Optional[pulumi.Input[bool]] = None,
                 expand_resources: Optional[pulumi.Input[bool]] = None,
                 inputs: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 lease_expire_at: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 owner: Optional[pulumi.Input[str]] = None,
                 project_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        This resource provides a way to create a deployment in vRealize Automation(vRA) by either using a blueprint, or catalog item, or an inline blueprint.

        ## Example Usage

        ## Import

        Deployment can be imported using the id, e.g.

        ```sh
         $ pulumi import vra:deployment/deployment:Deployment this 05956583-6488-4e7d-84c9-92a7b7219a15`
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] blueprint_content: vRA Cloud template content. Conflicts with `blueprint_id` and `catalog_item_id`.
        :param pulumi.Input[str] blueprint_id: Identifier of the requested blueprint in the form ‘UUID:version’.
        :param pulumi.Input[str] blueprint_version: The version of the vRA cloud template to request the deployment. Used only when `blueprint_id` is provided.
        :param pulumi.Input[str] catalog_item_id: The id of the vRA catalog item to request the deployment. Conflicts with `blueprint_id` and `blueprint_content`.
        :param pulumi.Input[str] catalog_item_version: The version of the vRA catalog item to request the deployment. Used only when `catalog_item_id` is provided.
        :param pulumi.Input[str] description: A human-friendly description.
        :param pulumi.Input[bool] expand_project: Flag to indicate whether to expand project information.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] inputs: Inputs provided by the user. For inputs including those with default values, refer to `inputs_including_defaults`.
        :param pulumi.Input[str] lease_expire_at: Time at which the deployment lease expires.
        :param pulumi.Input[str] name: A human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[str] owner: The user this deployment belongs to. At create, the owner is ignored but is used to update during next apply.
        :param pulumi.Input[str] project_id: The id of the project this entity belongs to.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DeploymentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource provides a way to create a deployment in vRealize Automation(vRA) by either using a blueprint, or catalog item, or an inline blueprint.

        ## Example Usage

        ## Import

        Deployment can be imported using the id, e.g.

        ```sh
         $ pulumi import vra:deployment/deployment:Deployment this 05956583-6488-4e7d-84c9-92a7b7219a15`
        ```

        :param str resource_name: The name of the resource.
        :param DeploymentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DeploymentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 blueprint_content: Optional[pulumi.Input[str]] = None,
                 blueprint_id: Optional[pulumi.Input[str]] = None,
                 blueprint_version: Optional[pulumi.Input[str]] = None,
                 catalog_item_id: Optional[pulumi.Input[str]] = None,
                 catalog_item_version: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 expand_last_request: Optional[pulumi.Input[bool]] = None,
                 expand_project: Optional[pulumi.Input[bool]] = None,
                 expand_resources: Optional[pulumi.Input[bool]] = None,
                 inputs: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 lease_expire_at: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 owner: Optional[pulumi.Input[str]] = None,
                 project_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DeploymentArgs.__new__(DeploymentArgs)

            __props__.__dict__["blueprint_content"] = blueprint_content
            __props__.__dict__["blueprint_id"] = blueprint_id
            __props__.__dict__["blueprint_version"] = blueprint_version
            __props__.__dict__["catalog_item_id"] = catalog_item_id
            __props__.__dict__["catalog_item_version"] = catalog_item_version
            __props__.__dict__["description"] = description
            if expand_last_request is not None and not opts.urn:
                warnings.warn("""Deprecated. True by default even if not provided.""", DeprecationWarning)
                pulumi.log.warn("""expand_last_request is deprecated: Deprecated. True by default even if not provided.""")
            __props__.__dict__["expand_last_request"] = expand_last_request
            __props__.__dict__["expand_project"] = expand_project
            if expand_resources is not None and not opts.urn:
                warnings.warn("""Deprecated. True by default even if not provided.""", DeprecationWarning)
                pulumi.log.warn("""expand_resources is deprecated: Deprecated. True by default even if not provided.""")
            __props__.__dict__["expand_resources"] = expand_resources
            __props__.__dict__["inputs"] = inputs
            __props__.__dict__["lease_expire_at"] = lease_expire_at
            __props__.__dict__["name"] = name
            __props__.__dict__["owner"] = owner
            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["created_at"] = None
            __props__.__dict__["created_by"] = None
            __props__.__dict__["expenses"] = None
            __props__.__dict__["inputs_including_defaults"] = None
            __props__.__dict__["last_requests"] = None
            __props__.__dict__["last_updated_at"] = None
            __props__.__dict__["last_updated_by"] = None
            __props__.__dict__["org_id"] = None
            __props__.__dict__["projects"] = None
            __props__.__dict__["resources"] = None
            __props__.__dict__["status"] = None
        super(Deployment, __self__).__init__(
            'vra:deployment/deployment:Deployment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            blueprint_content: Optional[pulumi.Input[str]] = None,
            blueprint_id: Optional[pulumi.Input[str]] = None,
            blueprint_version: Optional[pulumi.Input[str]] = None,
            catalog_item_id: Optional[pulumi.Input[str]] = None,
            catalog_item_version: Optional[pulumi.Input[str]] = None,
            created_at: Optional[pulumi.Input[str]] = None,
            created_by: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            expand_last_request: Optional[pulumi.Input[bool]] = None,
            expand_project: Optional[pulumi.Input[bool]] = None,
            expand_resources: Optional[pulumi.Input[bool]] = None,
            expenses: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DeploymentExpenseArgs']]]]] = None,
            inputs: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            inputs_including_defaults: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            last_requests: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DeploymentLastRequestArgs']]]]] = None,
            last_updated_at: Optional[pulumi.Input[str]] = None,
            last_updated_by: Optional[pulumi.Input[str]] = None,
            lease_expire_at: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            org_id: Optional[pulumi.Input[str]] = None,
            owner: Optional[pulumi.Input[str]] = None,
            project_id: Optional[pulumi.Input[str]] = None,
            projects: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DeploymentProjectArgs']]]]] = None,
            resources: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DeploymentResourceArgs']]]]] = None,
            status: Optional[pulumi.Input[str]] = None) -> 'Deployment':
        """
        Get an existing Deployment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] blueprint_content: vRA Cloud template content. Conflicts with `blueprint_id` and `catalog_item_id`.
        :param pulumi.Input[str] blueprint_id: Identifier of the requested blueprint in the form ‘UUID:version’.
        :param pulumi.Input[str] blueprint_version: The version of the vRA cloud template to request the deployment. Used only when `blueprint_id` is provided.
        :param pulumi.Input[str] catalog_item_id: The id of the vRA catalog item to request the deployment. Conflicts with `blueprint_id` and `blueprint_content`.
        :param pulumi.Input[str] catalog_item_version: The version of the vRA catalog item to request the deployment. Used only when `catalog_item_id` is provided.
        :param pulumi.Input[str] created_at: Creation time (e.g. date format ‘2019-07-13T23:16:49.310Z’).
        :param pulumi.Input[str] created_by: The user the entity was created by.
        :param pulumi.Input[str] description: A human-friendly description.
        :param pulumi.Input[bool] expand_project: Flag to indicate whether to expand project information.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DeploymentExpenseArgs']]]] expenses: Expense incurred for the deployment.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] inputs: Inputs provided by the user. For inputs including those with default values, refer to `inputs_including_defaults`.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] inputs_including_defaults: All the inputs applied during last create/update operation, including those with default values. For the list of inputs provided by the user in the configuration, refer to `inputs`.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DeploymentLastRequestArgs']]]] last_requests: Represents deployment requests.
        :param pulumi.Input[str] last_updated_at: Time at which the deployment was last updated.
        :param pulumi.Input[str] last_updated_by: The user that last updated the deployment.
        :param pulumi.Input[str] lease_expire_at: Time at which the deployment lease expires.
        :param pulumi.Input[str] name: A human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[str] org_id: The ID of the organization this deployment belongs to.
        :param pulumi.Input[str] owner: The user this deployment belongs to. At create, the owner is ignored but is used to update during next apply.
        :param pulumi.Input[str] project_id: The id of the project this entity belongs to.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DeploymentProjectArgs']]]] projects: The project this entity belongs to.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DeploymentResourceArgs']]]] resources: Expanded resources for the deployment. Content of this property will not be maintained backward compatible.
        :param pulumi.Input[str] status: Deployment status. Supported values are: `CREATE_SUCCESSFUL`, `CREATE_INPROGRESS`, `CREATE_FAILED`, `UPDATE_SUCCESSFUL`, `UPDATE_INPROGRESS`, `UPDATE_FAILED`, `DELETE_SUCCESSFUL`, `DELETE_INPROGRESS`, `DELETE_FAILED`, `ACTION_SUCCESSFUL`, `ACTION_INPROGRESS`, `ACTION_FAILED`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DeploymentState.__new__(_DeploymentState)

        __props__.__dict__["blueprint_content"] = blueprint_content
        __props__.__dict__["blueprint_id"] = blueprint_id
        __props__.__dict__["blueprint_version"] = blueprint_version
        __props__.__dict__["catalog_item_id"] = catalog_item_id
        __props__.__dict__["catalog_item_version"] = catalog_item_version
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["created_by"] = created_by
        __props__.__dict__["description"] = description
        __props__.__dict__["expand_last_request"] = expand_last_request
        __props__.__dict__["expand_project"] = expand_project
        __props__.__dict__["expand_resources"] = expand_resources
        __props__.__dict__["expenses"] = expenses
        __props__.__dict__["inputs"] = inputs
        __props__.__dict__["inputs_including_defaults"] = inputs_including_defaults
        __props__.__dict__["last_requests"] = last_requests
        __props__.__dict__["last_updated_at"] = last_updated_at
        __props__.__dict__["last_updated_by"] = last_updated_by
        __props__.__dict__["lease_expire_at"] = lease_expire_at
        __props__.__dict__["name"] = name
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["owner"] = owner
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["projects"] = projects
        __props__.__dict__["resources"] = resources
        __props__.__dict__["status"] = status
        return Deployment(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="blueprintContent")
    def blueprint_content(self) -> pulumi.Output[Optional[str]]:
        """
        vRA Cloud template content. Conflicts with `blueprint_id` and `catalog_item_id`.
        """
        return pulumi.get(self, "blueprint_content")

    @property
    @pulumi.getter(name="blueprintId")
    def blueprint_id(self) -> pulumi.Output[str]:
        """
        Identifier of the requested blueprint in the form ‘UUID:version’.
        """
        return pulumi.get(self, "blueprint_id")

    @property
    @pulumi.getter(name="blueprintVersion")
    def blueprint_version(self) -> pulumi.Output[str]:
        """
        The version of the vRA cloud template to request the deployment. Used only when `blueprint_id` is provided.
        """
        return pulumi.get(self, "blueprint_version")

    @property
    @pulumi.getter(name="catalogItemId")
    def catalog_item_id(self) -> pulumi.Output[str]:
        """
        The id of the vRA catalog item to request the deployment. Conflicts with `blueprint_id` and `blueprint_content`.
        """
        return pulumi.get(self, "catalog_item_id")

    @property
    @pulumi.getter(name="catalogItemVersion")
    def catalog_item_version(self) -> pulumi.Output[str]:
        """
        The version of the vRA catalog item to request the deployment. Used only when `catalog_item_id` is provided.
        """
        return pulumi.get(self, "catalog_item_version")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[str]:
        """
        Creation time (e.g. date format ‘2019-07-13T23:16:49.310Z’).
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> pulumi.Output[str]:
        """
        The user the entity was created by.
        """
        return pulumi.get(self, "created_by")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        A human-friendly description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="expandLastRequest")
    def expand_last_request(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "expand_last_request")

    @property
    @pulumi.getter(name="expandProject")
    def expand_project(self) -> pulumi.Output[Optional[bool]]:
        """
        Flag to indicate whether to expand project information.
        """
        return pulumi.get(self, "expand_project")

    @property
    @pulumi.getter(name="expandResources")
    def expand_resources(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "expand_resources")

    @property
    @pulumi.getter
    def expenses(self) -> pulumi.Output[Sequence['outputs.DeploymentExpense']]:
        """
        Expense incurred for the deployment.
        """
        return pulumi.get(self, "expenses")

    @property
    @pulumi.getter
    def inputs(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        Inputs provided by the user. For inputs including those with default values, refer to `inputs_including_defaults`.
        """
        return pulumi.get(self, "inputs")

    @property
    @pulumi.getter(name="inputsIncludingDefaults")
    def inputs_including_defaults(self) -> pulumi.Output[Mapping[str, str]]:
        """
        All the inputs applied during last create/update operation, including those with default values. For the list of inputs provided by the user in the configuration, refer to `inputs`.
        """
        return pulumi.get(self, "inputs_including_defaults")

    @property
    @pulumi.getter(name="lastRequests")
    def last_requests(self) -> pulumi.Output[Sequence['outputs.DeploymentLastRequest']]:
        """
        Represents deployment requests.
        """
        return pulumi.get(self, "last_requests")

    @property
    @pulumi.getter(name="lastUpdatedAt")
    def last_updated_at(self) -> pulumi.Output[str]:
        """
        Time at which the deployment was last updated.
        """
        return pulumi.get(self, "last_updated_at")

    @property
    @pulumi.getter(name="lastUpdatedBy")
    def last_updated_by(self) -> pulumi.Output[str]:
        """
        The user that last updated the deployment.
        """
        return pulumi.get(self, "last_updated_by")

    @property
    @pulumi.getter(name="leaseExpireAt")
    def lease_expire_at(self) -> pulumi.Output[str]:
        """
        Time at which the deployment lease expires.
        """
        return pulumi.get(self, "lease_expire_at")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        A human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[str]:
        """
        The ID of the organization this deployment belongs to.
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter
    def owner(self) -> pulumi.Output[str]:
        """
        The user this deployment belongs to. At create, the owner is ignored but is used to update during next apply.
        """
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[str]:
        """
        The id of the project this entity belongs to.
        """
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter
    def projects(self) -> pulumi.Output[Sequence['outputs.DeploymentProject']]:
        """
        The project this entity belongs to.
        """
        return pulumi.get(self, "projects")

    @property
    @pulumi.getter
    def resources(self) -> pulumi.Output[Sequence['outputs.DeploymentResource']]:
        """
        Expanded resources for the deployment. Content of this property will not be maintained backward compatible.
        """
        return pulumi.get(self, "resources")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        Deployment status. Supported values are: `CREATE_SUCCESSFUL`, `CREATE_INPROGRESS`, `CREATE_FAILED`, `UPDATE_SUCCESSFUL`, `UPDATE_INPROGRESS`, `UPDATE_FAILED`, `DELETE_SUCCESSFUL`, `DELETE_INPROGRESS`, `DELETE_FAILED`, `ACTION_SUCCESSFUL`, `ACTION_INPROGRESS`, `ACTION_FAILED`.
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetBlueprintResult',
    'AwaitableGetBlueprintResult',
    'get_blueprint',
    'get_blueprint_output',
]

@pulumi.output_type
class GetBlueprintResult:
    """
    A collection of values returned by getBlueprint.
    """
    def __init__(__self__, content=None, content_source_id=None, content_source_path=None, content_source_sync_at=None, content_source_sync_messages=None, content_source_sync_status=None, content_source_type=None, created_at=None, created_by=None, description=None, id=None, name=None, org_id=None, project_id=None, project_name=None, request_scope_org=None, self_link=None, status=None, total_released_versions=None, total_versions=None, updated_at=None, updated_by=None, valid=None, validation_messages=None):
        if content and not isinstance(content, str):
            raise TypeError("Expected argument 'content' to be a str")
        pulumi.set(__self__, "content", content)
        if content_source_id and not isinstance(content_source_id, str):
            raise TypeError("Expected argument 'content_source_id' to be a str")
        pulumi.set(__self__, "content_source_id", content_source_id)
        if content_source_path and not isinstance(content_source_path, str):
            raise TypeError("Expected argument 'content_source_path' to be a str")
        pulumi.set(__self__, "content_source_path", content_source_path)
        if content_source_sync_at and not isinstance(content_source_sync_at, str):
            raise TypeError("Expected argument 'content_source_sync_at' to be a str")
        pulumi.set(__self__, "content_source_sync_at", content_source_sync_at)
        if content_source_sync_messages and not isinstance(content_source_sync_messages, list):
            raise TypeError("Expected argument 'content_source_sync_messages' to be a list")
        pulumi.set(__self__, "content_source_sync_messages", content_source_sync_messages)
        if content_source_sync_status and not isinstance(content_source_sync_status, str):
            raise TypeError("Expected argument 'content_source_sync_status' to be a str")
        pulumi.set(__self__, "content_source_sync_status", content_source_sync_status)
        if content_source_type and not isinstance(content_source_type, str):
            raise TypeError("Expected argument 'content_source_type' to be a str")
        pulumi.set(__self__, "content_source_type", content_source_type)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if created_by and not isinstance(created_by, str):
            raise TypeError("Expected argument 'created_by' to be a str")
        pulumi.set(__self__, "created_by", created_by)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if request_scope_org and not isinstance(request_scope_org, bool):
            raise TypeError("Expected argument 'request_scope_org' to be a bool")
        pulumi.set(__self__, "request_scope_org", request_scope_org)
        if self_link and not isinstance(self_link, str):
            raise TypeError("Expected argument 'self_link' to be a str")
        pulumi.set(__self__, "self_link", self_link)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if total_released_versions and not isinstance(total_released_versions, int):
            raise TypeError("Expected argument 'total_released_versions' to be a int")
        pulumi.set(__self__, "total_released_versions", total_released_versions)
        if total_versions and not isinstance(total_versions, int):
            raise TypeError("Expected argument 'total_versions' to be a int")
        pulumi.set(__self__, "total_versions", total_versions)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)
        if updated_by and not isinstance(updated_by, str):
            raise TypeError("Expected argument 'updated_by' to be a str")
        pulumi.set(__self__, "updated_by", updated_by)
        if valid and not isinstance(valid, bool):
            raise TypeError("Expected argument 'valid' to be a bool")
        pulumi.set(__self__, "valid", valid)
        if validation_messages and not isinstance(validation_messages, list):
            raise TypeError("Expected argument 'validation_messages' to be a list")
        pulumi.set(__self__, "validation_messages", validation_messages)

    @property
    @pulumi.getter
    def content(self) -> str:
        """
        Blueprint YAML content.
        """
        return pulumi.get(self, "content")

    @property
    @pulumi.getter(name="contentSourceId")
    def content_source_id(self) -> str:
        """
        The id of the content source.
        """
        return pulumi.get(self, "content_source_id")

    @property
    @pulumi.getter(name="contentSourcePath")
    def content_source_path(self) -> str:
        """
        Content source path.
        """
        return pulumi.get(self, "content_source_path")

    @property
    @pulumi.getter(name="contentSourceSyncAt")
    def content_source_sync_at(self) -> str:
        """
        Content source last sync at.
        """
        return pulumi.get(self, "content_source_sync_at")

    @property
    @pulumi.getter(name="contentSourceSyncMessages")
    def content_source_sync_messages(self) -> Sequence[str]:
        """
        Content source last sync messages.
        """
        return pulumi.get(self, "content_source_sync_messages")

    @property
    @pulumi.getter(name="contentSourceSyncStatus")
    def content_source_sync_status(self) -> str:
        """
        Content source last sync status. Supported values: `SUCCESSFUL`, `FAILED`.
        """
        return pulumi.get(self, "content_source_sync_status")

    @property
    @pulumi.getter(name="contentSourceType")
    def content_source_type(self) -> str:
        """
        Content source type.
        """
        return pulumi.get(self, "content_source_type")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> str:
        """
        Date when the entity was created. The date is in ISO 6801 and UTC.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> str:
        """
        The user the entity was created by.
        """
        return pulumi.get(self, "created_by")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        A human-friendly description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> str:
        """
        The id of the organization this entity belongs to.
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> str:
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> str:
        """
        The name of the project the entity belongs to.
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="requestScopeOrg")
    def request_scope_org(self) -> bool:
        """
        Flag to indicate whether this blueprint can be requested from any project in the organization this entity belongs to.
        """
        return pulumi.get(self, "request_scope_org")

    @property
    @pulumi.getter(name="selfLink")
    def self_link(self) -> str:
        """
        HATEOAS of the entity.
        """
        return pulumi.get(self, "self_link")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        Status of the cloud template. Supported values: `DRAFT`, `VERSIONED`, `RELEASED`.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="totalReleasedVersions")
    def total_released_versions(self) -> int:
        """
        Total number of released versions.
        """
        return pulumi.get(self, "total_released_versions")

    @property
    @pulumi.getter(name="totalVersions")
    def total_versions(self) -> int:
        """
        Total number of versions.
        """
        return pulumi.get(self, "total_versions")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> str:
        """
        Date when the entity was last updated. The date is ISO 8601 and UTC.
        """
        return pulumi.get(self, "updated_at")

    @property
    @pulumi.getter(name="updatedBy")
    def updated_by(self) -> str:
        """
        The user the entity was last updated by.
        """
        return pulumi.get(self, "updated_by")

    @property
    @pulumi.getter
    def valid(self) -> bool:
        """
        Flag to indicate if the current content of the cloud template is valid.
        """
        return pulumi.get(self, "valid")

    @property
    @pulumi.getter(name="validationMessages")
    def validation_messages(self) -> Sequence['outputs.GetBlueprintValidationMessageResult']:
        """
        List of validations messages.
        * message - Validation message.
        """
        return pulumi.get(self, "validation_messages")


class AwaitableGetBlueprintResult(GetBlueprintResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetBlueprintResult(
            content=self.content,
            content_source_id=self.content_source_id,
            content_source_path=self.content_source_path,
            content_source_sync_at=self.content_source_sync_at,
            content_source_sync_messages=self.content_source_sync_messages,
            content_source_sync_status=self.content_source_sync_status,
            content_source_type=self.content_source_type,
            created_at=self.created_at,
            created_by=self.created_by,
            description=self.description,
            id=self.id,
            name=self.name,
            org_id=self.org_id,
            project_id=self.project_id,
            project_name=self.project_name,
            request_scope_org=self.request_scope_org,
            self_link=self.self_link,
            status=self.status,
            total_released_versions=self.total_released_versions,
            total_versions=self.total_versions,
            updated_at=self.updated_at,
            updated_by=self.updated_by,
            valid=self.valid,
            validation_messages=self.validation_messages)


def get_blueprint(id: Optional[str] = None,
                  name: Optional[str] = None,
                  project_id: Optional[str] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetBlueprintResult:
    """
    This data source provides information about a cloud template (blueprint) in vRA.

    ## Example Usage
    ### S

    This is an example of how to get a vRA cloud template by its name.

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.blueprint.get_blueprint(name=vra_blueprint["this"]["name"])
    ```

    This is an example of how to get a vRA cloud template by its id.

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.blueprint.get_blueprint(id=vra_blueprint["this"]["id"])
    ```


    :param str id: The id of this cloud template. One of `id` or `name` must be provided.
    :param str name: Name of the cloud template. One of `id` or `name` must be provided.
    :param str project_id: The id of the project to narrow the search while looking for cloud templates.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vra:blueprint/getBlueprint:getBlueprint', __args__, opts=opts, typ=GetBlueprintResult).value

    return AwaitableGetBlueprintResult(
        content=__ret__.content,
        content_source_id=__ret__.content_source_id,
        content_source_path=__ret__.content_source_path,
        content_source_sync_at=__ret__.content_source_sync_at,
        content_source_sync_messages=__ret__.content_source_sync_messages,
        content_source_sync_status=__ret__.content_source_sync_status,
        content_source_type=__ret__.content_source_type,
        created_at=__ret__.created_at,
        created_by=__ret__.created_by,
        description=__ret__.description,
        id=__ret__.id,
        name=__ret__.name,
        org_id=__ret__.org_id,
        project_id=__ret__.project_id,
        project_name=__ret__.project_name,
        request_scope_org=__ret__.request_scope_org,
        self_link=__ret__.self_link,
        status=__ret__.status,
        total_released_versions=__ret__.total_released_versions,
        total_versions=__ret__.total_versions,
        updated_at=__ret__.updated_at,
        updated_by=__ret__.updated_by,
        valid=__ret__.valid,
        validation_messages=__ret__.validation_messages)


@_utilities.lift_output_func(get_blueprint)
def get_blueprint_output(id: Optional[pulumi.Input[Optional[str]]] = None,
                         name: Optional[pulumi.Input[Optional[str]]] = None,
                         project_id: Optional[pulumi.Input[Optional[str]]] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetBlueprintResult]:
    """
    This data source provides information about a cloud template (blueprint) in vRA.

    ## Example Usage
    ### S

    This is an example of how to get a vRA cloud template by its name.

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.blueprint.get_blueprint(name=vra_blueprint["this"]["name"])
    ```

    This is an example of how to get a vRA cloud template by its id.

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.blueprint.get_blueprint(id=vra_blueprint["this"]["id"])
    ```


    :param str id: The id of this cloud template. One of `id` or `name` must be provided.
    :param str name: Name of the cloud template. One of `id` or `name` must be provided.
    :param str project_id: The id of the project to narrow the search while looking for cloud templates.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetDeploymentResult',
    'AwaitableGetDeploymentResult',
    'get_deployment',
    'get_deployment_output',
]

@pulumi.output_type
class GetDeploymentResult:
    """
    A collection of values returned by getDeployment.
    """
    def __init__(__self__, blueprint_content=None, blueprint_id=None, blueprint_version=None, catalog_item_id=None, catalog_item_version=None, created_at=None, created_by=None, description=None, expand_last_request=None, expand_project=None, expand_resources=None, expenses=None, id=None, inputs=None, last_requests=None, last_updated_at=None, last_updated_by=None, lease_expire_at=None, name=None, org_id=None, owner=None, project_id=None, projects=None, resources=None, status=None):
        if blueprint_content and not isinstance(blueprint_content, str):
            raise TypeError("Expected argument 'blueprint_content' to be a str")
        pulumi.set(__self__, "blueprint_content", blueprint_content)
        if blueprint_id and not isinstance(blueprint_id, str):
            raise TypeError("Expected argument 'blueprint_id' to be a str")
        pulumi.set(__self__, "blueprint_id", blueprint_id)
        if blueprint_version and not isinstance(blueprint_version, str):
            raise TypeError("Expected argument 'blueprint_version' to be a str")
        pulumi.set(__self__, "blueprint_version", blueprint_version)
        if catalog_item_id and not isinstance(catalog_item_id, str):
            raise TypeError("Expected argument 'catalog_item_id' to be a str")
        pulumi.set(__self__, "catalog_item_id", catalog_item_id)
        if catalog_item_version and not isinstance(catalog_item_version, str):
            raise TypeError("Expected argument 'catalog_item_version' to be a str")
        pulumi.set(__self__, "catalog_item_version", catalog_item_version)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if created_by and not isinstance(created_by, str):
            raise TypeError("Expected argument 'created_by' to be a str")
        pulumi.set(__self__, "created_by", created_by)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if expand_last_request and not isinstance(expand_last_request, bool):
            raise TypeError("Expected argument 'expand_last_request' to be a bool")
        pulumi.set(__self__, "expand_last_request", expand_last_request)
        if expand_project and not isinstance(expand_project, bool):
            raise TypeError("Expected argument 'expand_project' to be a bool")
        pulumi.set(__self__, "expand_project", expand_project)
        if expand_resources and not isinstance(expand_resources, bool):
            raise TypeError("Expected argument 'expand_resources' to be a bool")
        pulumi.set(__self__, "expand_resources", expand_resources)
        if expenses and not isinstance(expenses, list):
            raise TypeError("Expected argument 'expenses' to be a list")
        pulumi.set(__self__, "expenses", expenses)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if inputs and not isinstance(inputs, dict):
            raise TypeError("Expected argument 'inputs' to be a dict")
        pulumi.set(__self__, "inputs", inputs)
        if last_requests and not isinstance(last_requests, list):
            raise TypeError("Expected argument 'last_requests' to be a list")
        pulumi.set(__self__, "last_requests", last_requests)
        if last_updated_at and not isinstance(last_updated_at, str):
            raise TypeError("Expected argument 'last_updated_at' to be a str")
        pulumi.set(__self__, "last_updated_at", last_updated_at)
        if last_updated_by and not isinstance(last_updated_by, str):
            raise TypeError("Expected argument 'last_updated_by' to be a str")
        pulumi.set(__self__, "last_updated_by", last_updated_by)
        if lease_expire_at and not isinstance(lease_expire_at, str):
            raise TypeError("Expected argument 'lease_expire_at' to be a str")
        pulumi.set(__self__, "lease_expire_at", lease_expire_at)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if owner and not isinstance(owner, str):
            raise TypeError("Expected argument 'owner' to be a str")
        pulumi.set(__self__, "owner", owner)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if projects and not isinstance(projects, list):
            raise TypeError("Expected argument 'projects' to be a list")
        pulumi.set(__self__, "projects", projects)
        if resources and not isinstance(resources, list):
            raise TypeError("Expected argument 'resources' to be a list")
        pulumi.set(__self__, "resources", resources)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="blueprintContent")
    def blueprint_content(self) -> str:
        """
        vRA Cloud template content. Conflicts with `blueprint_id` and `catalog_item_id`.
        """
        return pulumi.get(self, "blueprint_content")

    @property
    @pulumi.getter(name="blueprintId")
    def blueprint_id(self) -> str:
        """
        Identifier of the requested blueprint in the form ‘UUID:version’.
        """
        return pulumi.get(self, "blueprint_id")

    @property
    @pulumi.getter(name="blueprintVersion")
    def blueprint_version(self) -> str:
        """
        The version of the vRA cloud template to request the deployment. Used only when `blueprint_id` is provided.
        """
        return pulumi.get(self, "blueprint_version")

    @property
    @pulumi.getter(name="catalogItemId")
    def catalog_item_id(self) -> str:
        """
        Identifier of the requested catalog item in the form ‘UUID:version’.
        """
        return pulumi.get(self, "catalog_item_id")

    @property
    @pulumi.getter(name="catalogItemVersion")
    def catalog_item_version(self) -> str:
        """
        The version of the vRA catalog item to request the deployment. Used only when `catalog_item_id` is provided.
        """
        return pulumi.get(self, "catalog_item_version")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> str:
        """
        Creation time (e.g. date format ‘2019-07-13T23:16:49.310Z’).
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> str:
        """
        The user the entity was created by.
        """
        return pulumi.get(self, "created_by")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        A description of the resource.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="expandLastRequest")
    def expand_last_request(self) -> Optional[bool]:
        return pulumi.get(self, "expand_last_request")

    @property
    @pulumi.getter(name="expandProject")
    def expand_project(self) -> Optional[bool]:
        return pulumi.get(self, "expand_project")

    @property
    @pulumi.getter(name="expandResources")
    def expand_resources(self) -> Optional[bool]:
        return pulumi.get(self, "expand_resources")

    @property
    @pulumi.getter
    def expenses(self) -> Sequence['outputs.GetDeploymentExpenseResult']:
        """
        Expense incurred for this resource.
        """
        return pulumi.get(self, "expenses")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def inputs(self) -> Mapping[str, str]:
        """
        List of request inputs.
        """
        return pulumi.get(self, "inputs")

    @property
    @pulumi.getter(name="lastRequests")
    def last_requests(self) -> Sequence['outputs.GetDeploymentLastRequestResult']:
        """
        Represents deployment requests.
        """
        return pulumi.get(self, "last_requests")

    @property
    @pulumi.getter(name="lastUpdatedAt")
    def last_updated_at(self) -> str:
        """
        Time at which the deployment was last updated.
        """
        return pulumi.get(self, "last_updated_at")

    @property
    @pulumi.getter(name="lastUpdatedBy")
    def last_updated_by(self) -> str:
        """
        The user that last updated the deployment.
        """
        return pulumi.get(self, "last_updated_by")

    @property
    @pulumi.getter(name="leaseExpireAt")
    def lease_expire_at(self) -> str:
        """
        Time at which the deployment lease expires.
        """
        return pulumi.get(self, "lease_expire_at")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> str:
        """
        The ID of the organization this deployment belongs to.
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter
    def owner(self) -> Optional[str]:
        """
        The user this deployment belongs to.
        """
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> str:
        """
        The id of the project this deployment belongs to.
        """
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter
    def projects(self) -> Sequence['outputs.GetDeploymentProjectResult']:
        """
        The project this entity belongs to.
        """
        return pulumi.get(self, "projects")

    @property
    @pulumi.getter
    def resources(self) -> Sequence['outputs.GetDeploymentResourceResult']:
        """
        Expanded resources for the deployment. Content of this property will not be maintained backward compatible.
        """
        return pulumi.get(self, "resources")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        Deployment status. Supported values are: `CREATE_SUCCESSFUL`, `CREATE_INPROGRESS`, `CREATE_FAILED`, `UPDATE_SUCCESSFUL`, `UPDATE_INPROGRESS`, `UPDATE_FAILED`, `DELETE_SUCCESSFUL`, `DELETE_INPROGRESS`, `DELETE_FAILED`, `ACTION_SUCCESSFUL`, `ACTION_INPROGRESS`, `ACTION_FAILED`.
        """
        return pulumi.get(self, "status")


class AwaitableGetDeploymentResult(GetDeploymentResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDeploymentResult(
            blueprint_content=self.blueprint_content,
            blueprint_id=self.blueprint_id,
            blueprint_version=self.blueprint_version,
            catalog_item_id=self.catalog_item_id,
            catalog_item_version=self.catalog_item_version,
            created_at=self.created_at,
            created_by=self.created_by,
            description=self.description,
            expand_last_request=self.expand_last_request,
            expand_project=self.expand_project,
            expand_resources=self.expand_resources,
            expenses=self.expenses,
            id=self.id,
            inputs=self.inputs,
            last_requests=self.last_requests,
            last_updated_at=self.last_updated_at,
            last_updated_by=self.last_updated_by,
            lease_expire_at=self.lease_expire_at,
            name=self.name,
            org_id=self.org_id,
            owner=self.owner,
            project_id=self.project_id,
            projects=self.projects,
            resources=self.resources,
            status=self.status)


def get_deployment(blueprint_content: Optional[str] = None,
                   blueprint_id: Optional[str] = None,
                   blueprint_version: Optional[str] = None,
                   catalog_item_id: Optional[str] = None,
                   catalog_item_version: Optional[str] = None,
                   created_at: Optional[str] = None,
                   created_by: Optional[str] = None,
                   description: Optional[str] = None,
                   expand_last_request: Optional[bool] = None,
                   expand_project: Optional[bool] = None,
                   expand_resources: Optional[bool] = None,
                   id: Optional[str] = None,
                   inputs: Optional[Mapping[str, str]] = None,
                   last_updated_at: Optional[str] = None,
                   last_updated_by: Optional[str] = None,
                   lease_expire_at: Optional[str] = None,
                   name: Optional[str] = None,
                   owner: Optional[str] = None,
                   project_id: Optional[str] = None,
                   status: Optional[str] = None,
                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDeploymentResult:
    """
    This data source provides information about a deployment in vRA.

    ## Example Usage
    ### S

    This is an example of how to get a vRA deployment by its name.

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.deployment.get_deployment(name=var["deployment_name"])
    ```

    This is an example of how to get a vRA cloud template by its id.

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.deployment.get_deployment(id=var["deployment_id"])
    ```


    :param str blueprint_content: vRA Cloud template content. Conflicts with `blueprint_id` and `catalog_item_id`.
    :param str blueprint_id: Identifier of the requested blueprint in the form ‘UUID:version’.
    :param str blueprint_version: The version of the vRA cloud template to request the deployment. Used only when `blueprint_id` is provided.
    :param str catalog_item_id: Identifier of the requested catalog item in the form ‘UUID:version’.
    :param str catalog_item_version: The version of the vRA catalog item to request the deployment. Used only when `catalog_item_id` is provided.
    :param str created_at: Creation time (e.g. date format ‘2019-07-13T23:16:49.310Z’).
    :param str created_by: The user the entity was created by.
    :param str description: A description of the resource.
    :param bool expand_last_request: Flag to indicate whether to expand last request on the deployment.
    :param bool expand_project: Flag to indicate whether to expand project information.
    :param bool expand_resources: Flag to indicate whether to expand resources in the deployment.
    :param str id: The id of the deployment. One of `id` or `name` must be provided.
    :param Mapping[str, str] inputs: List of request inputs.
    :param str last_updated_at: Time at which the deployment was last updated.
    :param str last_updated_by: The user that last updated the deployment.
    :param str lease_expire_at: Time at which the deployment lease expires.
    :param str name: Name of the deployment. One of `id` or `name` must be provided.
    :param str owner: The user this deployment belongs to.
    :param str project_id: The id of the project this deployment belongs to.
    :param str status: Deployment status. Supported values are: `CREATE_SUCCESSFUL`, `CREATE_INPROGRESS`, `CREATE_FAILED`, `UPDATE_SUCCESSFUL`, `UPDATE_INPROGRESS`, `UPDATE_FAILED`, `DELETE_SUCCESSFUL`, `DELETE_INPROGRESS`, `DELETE_FAILED`, `ACTION_SUCCESSFUL`, `ACTION_INPROGRESS`, `ACTION_FAILED`.
    """
    __args__ = dict()
    __args__['blueprintContent'] = blueprint_content
    __args__['blueprintId'] = blueprint_id
    __args__['blueprintVersion'] = blueprint_version
    __args__['catalogItemId'] = catalog_item_id
    __args__['catalogItemVersion'] = catalog_item_version
    __args__['createdAt'] = created_at
    __args__['createdBy'] = created_by
    __args__['description'] = description
    __args__['expandLastRequest'] = expand_last_request
    __args__['expandProject'] = expand_project
    __args__['expandResources'] = expand_resources
    __args__['id'] = id
    __args__['inputs'] = inputs
    __args__['lastUpdatedAt'] = last_updated_at
    __args__['lastUpdatedBy'] = last_updated_by
    __args__['leaseExpireAt'] = lease_expire_at
    __args__['name'] = name
    __args__['owner'] = owner
    __args__['projectId'] = project_id
    __args__['status'] = status
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vra:deployment/getDeployment:getDeployment', __args__, opts=opts, typ=GetDeploymentResult).value

    return AwaitableGetDeploymentResult(
        blueprint_content=__ret__.blueprint_content,
        blueprint_id=__ret__.blueprint_id,
        blueprint_version=__ret__.blueprint_version,
        catalog_item_id=__ret__.catalog_item_id,
        catalog_item_version=__ret__.catalog_item_version,
        created_at=__ret__.created_at,
        created_by=__ret__.created_by,
        description=__ret__.description,
        expand_last_request=__ret__.expand_last_request,
        expand_project=__ret__.expand_project,
        expand_resources=__ret__.expand_resources,
        expenses=__ret__.expenses,
        id=__ret__.id,
        inputs=__ret__.inputs,
        last_requests=__ret__.last_requests,
        last_updated_at=__ret__.last_updated_at,
        last_updated_by=__ret__.last_updated_by,
        lease_expire_at=__ret__.lease_expire_at,
        name=__ret__.name,
        org_id=__ret__.org_id,
        owner=__ret__.owner,
        project_id=__ret__.project_id,
        projects=__ret__.projects,
        resources=__ret__.resources,
        status=__ret__.status)


@_utilities.lift_output_func(get_deployment)
def get_deployment_output(blueprint_content: Optional[pulumi.Input[Optional[str]]] = None,
                          blueprint_id: Optional[pulumi.Input[Optional[str]]] = None,
                          blueprint_version: Optional[pulumi.Input[Optional[str]]] = None,
                          catalog_item_id: Optional[pulumi.Input[Optional[str]]] = None,
                          catalog_item_version: Optional[pulumi.Input[Optional[str]]] = None,
                          created_at: Optional[pulumi.Input[Optional[str]]] = None,
                          created_by: Optional[pulumi.Input[Optional[str]]] = None,
                          description: Optional[pulumi.Input[Optional[str]]] = None,
                          expand_last_request: Optional[pulumi.Input[Optional[bool]]] = None,
                          expand_project: Optional[pulumi.Input[Optional[bool]]] = None,
                          expand_resources: Optional[pulumi.Input[Optional[bool]]] = None,
                          id: Optional[pulumi.Input[Optional[str]]] = None,
                          inputs: Optional[pulumi.Input[Optional[Mapping[str, str]]]] = None,
                          last_updated_at: Optional[pulumi.Input[Optional[str]]] = None,
                          last_updated_by: Optional[pulumi.Input[Optional[str]]] = None,
                          lease_expire_at: Optional[pulumi.Input[Optional[str]]] = None,
                          name: Optional[pulumi.Input[Optional[str]]] = None,
                          owner: Optional[pulumi.Input[Optional[str]]] = None,
                          project_id: Optional[pulumi.Input[Optional[str]]] = None,
                          status: Optional[pulumi.Input[Optional[str]]] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetDeploymentResult]:
    """
    This data source provides information about a deployment in vRA.

    ## Example Usage
    ### S

    This is an example of how to get a vRA deployment by its name.

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.deployment.get_deployment(name=var["deployment_name"])
    ```

    This is an example of how to get a vRA cloud template by its id.

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.deployment.get_deployment(id=var["deployment_id"])
    ```


    :param str blueprint_content: vRA Cloud template content. Conflicts with `blueprint_id` and `catalog_item_id`.
    :param str blueprint_id: Identifier of the requested blueprint in the form ‘UUID:version’.
    :param str blueprint_version: The version of the vRA cloud template to request the deployment. Used only when `blueprint_id` is provided.
    :param str catalog_item_id: Identifier of the requested catalog item in the form ‘UUID:version’.
    :param str catalog_item_version: The version of the vRA catalog item to request the deployment. Used only when `catalog_item_id` is provided.
    :param str created_at: Creation time (e.g. date format ‘2019-07-13T23:16:49.310Z’).
    :param str created_by: The user the entity was created by.
    :param str description: A description of the resource.
    :param bool expand_last_request: Flag to indicate whether to expand last request on the deployment.
    :param bool expand_project: Flag to indicate whether to expand project information.
    :param bool expand_resources: Flag to indicate whether to expand resources in the deployment.
    :param str id: The id of the deployment. One of `id` or `name` must be provided.
    :param Mapping[str, str] inputs: List of request inputs.
    :param str last_updated_at: Time at which the deployment was last updated.
    :param str last_updated_by: The user that last updated the deployment.
    :param str lease_expire_at: Time at which the deployment lease expires.
    :param str name: Name of the deployment. One of `id` or `name` must be provided.
    :param str owner: The user this deployment belongs to.
    :param str project_id: The id of the project this deployment belongs to.
    :param str status: Deployment status. Supported values are: `CREATE_SUCCESSFUL`, `CREATE_INPROGRESS`, `CREATE_FAILED`, `UPDATE_SUCCESSFUL`, `UPDATE_INPROGRESS`, `UPDATE_FAILED`, `DELETE_SUCCESSFUL`, `DELETE_INPROGRESS`, `DELETE_FAILED`, `ACTION_SUCCESSFUL`, `ACTION_INPROGRESS`, `ACTION_FAILED`.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetProfileResult',
    'AwaitableGetProfileResult',
    'get_profile',
    'get_profile_output',
]

@pulumi.output_type
class GetProfileResult:
    """
    A collection of values returned by getProfile.
    """
    def __init__(__self__, created_at=None, description=None, external_region_id=None, filter=None, id=None, image_mappings=None, name=None, owner=None, region_id=None, updated_at=None):
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if external_region_id and not isinstance(external_region_id, str):
            raise TypeError("Expected argument 'external_region_id' to be a str")
        pulumi.set(__self__, "external_region_id", external_region_id)
        if filter and not isinstance(filter, str):
            raise TypeError("Expected argument 'filter' to be a str")
        pulumi.set(__self__, "filter", filter)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if image_mappings and not isinstance(image_mappings, list):
            raise TypeError("Expected argument 'image_mappings' to be a list")
        pulumi.set(__self__, "image_mappings", image_mappings)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if owner and not isinstance(owner, str):
            raise TypeError("Expected argument 'owner' to be a str")
        pulumi.set(__self__, "owner", owner)
        if region_id and not isinstance(region_id, str):
            raise TypeError("Expected argument 'region_id' to be a str")
        pulumi.set(__self__, "region_id", region_id)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> str:
        """
        Date when the entity was created. The date is in ISO 6801 and UTC.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def description(self) -> Optional[str]:
        """
        A human-friendly description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="externalRegionId")
    def external_region_id(self) -> str:
        """
        The external regionId of the resource.
        """
        return pulumi.get(self, "external_region_id")

    @property
    @pulumi.getter
    def filter(self) -> Optional[str]:
        return pulumi.get(self, "filter")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="imageMappings")
    def image_mappings(self) -> Optional[Sequence['outputs.GetProfileImageMappingResult']]:
        """
        Image mapping defined for the corresponding region.
        """
        return pulumi.get(self, "image_mappings")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def owner(self) -> str:
        """
        Email of the user that owns the entity.
        """
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> str:
        return pulumi.get(self, "region_id")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> str:
        """
        Date when the entity was last updated. The date is ISO 8601 and UTC.
        """
        return pulumi.get(self, "updated_at")


class AwaitableGetProfileResult(GetProfileResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProfileResult(
            created_at=self.created_at,
            description=self.description,
            external_region_id=self.external_region_id,
            filter=self.filter,
            id=self.id,
            image_mappings=self.image_mappings,
            name=self.name,
            owner=self.owner,
            region_id=self.region_id,
            updated_at=self.updated_at)


def get_profile(description: Optional[str] = None,
                filter: Optional[str] = None,
                id: Optional[str] = None,
                image_mappings: Optional[Sequence[pulumi.InputType['GetProfileImageMappingArgs']]] = None,
                name: Optional[str] = None,
                region_id: Optional[str] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetProfileResult:
    """
    ## Example Usage
    ### S
    This is an example of how to read an image profile as data source.

    **Image profile data source by its id:**

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.image.get_profile(filter="name eq 'foobar'")
    ```

    **Vra image profile data source filter by region id:**

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.image.get_profile(region_id=vra_image_profile["this"]["region_id"])
    ```

    An image profile data source supports the following arguments:


    :param str description: A human-friendly description.
    :param str filter: Filter query string that is supported by vRA multi-cloud IaaS API. Example: regionId eq '<regionId>' and cloudAccountId eq '<cloudAccountId>'.
    :param str id: The id of the image profile instance.
    :param Sequence[pulumi.InputType['GetProfileImageMappingArgs']] image_mappings: Image mapping defined for the corresponding region.
    :param str name: A human-friendly name used as an identifier in APIs that support this option.
    :param str region_id: The id of the region for which this profile is defined as in vRealize Automation(vRA).
    """
    __args__ = dict()
    __args__['description'] = description
    __args__['filter'] = filter
    __args__['id'] = id
    __args__['imageMappings'] = image_mappings
    __args__['name'] = name
    __args__['regionId'] = region_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vra:image/getProfile:getProfile', __args__, opts=opts, typ=GetProfileResult).value

    return AwaitableGetProfileResult(
        created_at=__ret__.created_at,
        description=__ret__.description,
        external_region_id=__ret__.external_region_id,
        filter=__ret__.filter,
        id=__ret__.id,
        image_mappings=__ret__.image_mappings,
        name=__ret__.name,
        owner=__ret__.owner,
        region_id=__ret__.region_id,
        updated_at=__ret__.updated_at)


@_utilities.lift_output_func(get_profile)
def get_profile_output(description: Optional[pulumi.Input[Optional[str]]] = None,
                       filter: Optional[pulumi.Input[Optional[str]]] = None,
                       id: Optional[pulumi.Input[Optional[str]]] = None,
                       image_mappings: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetProfileImageMappingArgs']]]]] = None,
                       name: Optional[pulumi.Input[Optional[str]]] = None,
                       region_id: Optional[pulumi.Input[Optional[str]]] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetProfileResult]:
    """
    ## Example Usage
    ### S
    This is an example of how to read an image profile as data source.

    **Image profile data source by its id:**

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.image.get_profile(filter="name eq 'foobar'")
    ```

    **Vra image profile data source filter by region id:**

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.image.get_profile(region_id=vra_image_profile["this"]["region_id"])
    ```

    An image profile data source supports the following arguments:


    :param str description: A human-friendly description.
    :param str filter: Filter query string that is supported by vRA multi-cloud IaaS API. Example: regionId eq '<regionId>' and cloudAccountId eq '<cloudAccountId>'.
    :param str id: The id of the image profile instance.
    :param Sequence[pulumi.InputType['GetProfileImageMappingArgs']] image_mappings: Image mapping defined for the corresponding region.
    :param str name: A human-friendly name used as an identifier in APIs that support this option.
    :param str region_id: The id of the region for which this profile is defined as in vRealize Automation(vRA).
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetImageResult',
    'AwaitableGetImageResult',
    'get_image',
    'get_image_output',
]

@pulumi.output_type
class GetImageResult:
    """
    A collection of values returned by getImage.
    """
    def __init__(__self__, description=None, external_id=None, filter=None, id=None, name=None, private=None, region=None):
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if external_id and not isinstance(external_id, str):
            raise TypeError("Expected argument 'external_id' to be a str")
        pulumi.set(__self__, "external_id", external_id)
        if filter and not isinstance(filter, str):
            raise TypeError("Expected argument 'filter' to be a str")
        pulumi.set(__self__, "filter", filter)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if private and not isinstance(private, bool):
            raise TypeError("Expected argument 'private' to be a bool")
        pulumi.set(__self__, "private", private)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        A human-friendly description of the image.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="externalId")
    def external_id(self) -> str:
        """
        External entity id on the provider side.
        """
        return pulumi.get(self, "external_id")

    @property
    @pulumi.getter
    def filter(self) -> str:
        return pulumi.get(self, "filter")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The id of the image.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        A human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def private(self) -> bool:
        """
        Indicates whether this image is private. For vSphere, private images are templates and snapshots and public images are content library items.
        """
        return pulumi.get(self, "private")

    @property
    @pulumi.getter
    def region(self) -> str:
        """
        The regionId of the image. For a vSphere cloud account, it is the `externalRegionId` such as `Datacenter:datacenter-2` and for an AWS cloud account, it is region name such as `us-east-1`, etc.
        """
        return pulumi.get(self, "region")


class AwaitableGetImageResult(GetImageResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetImageResult(
            description=self.description,
            external_id=self.external_id,
            filter=self.filter,
            id=self.id,
            name=self.name,
            private=self.private,
            region=self.region)


def get_image(filter: Optional[str] = None,
              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetImageResult:
    """
    The `image.get_image` data source can be used to discover the lookup machine images with cloud accounts. This can then be used with resource that require an image. For example, to create an image profile using the `image.Profile` resource.

    ## Example Usage

    This is an example of how to lookup images from a vSphere cloud account.

    ```python
    import pulumi
    import pulumi_vra as vra
    import pulumiverse_vra as vra

    this_v_sphere = vra.cloudaccount.get_v_sphere(name=var["cloud_account"])
    this_region = vra.region.get_region(cloud_account_id=this_v_sphere.id,
        region=var["region"])
    image0 = vra.image.get_image(filter=f"name eq '{var['image_name_0']}' and cloudAccountId eq '{this_v_sphere.id}' and externalRegionId eq '{var['region']}'")
    image1 = vra.image.get_image(filter=f"name eq '{var['image_name_1']}' and cloudAccountId eq '{this_v_sphere.id}' and externalRegionId eq '{var['region']}'")
    this_profile = vra.image.Profile("thisProfile",
        description=var["image_profile_description"],
        region_id=this_region.id,
        image_mappings=[
            vra.image.ProfileImageMappingArgs(
                name=var["image_name_0"],
                image_id=image0.id,
            ),
            vra.image.ProfileImageMappingArgs(
                name=var["image_name_1"],
                image_id=image1.id,
            ),
        ])
    ```


    :param str filter: Search criteria to narrow down the image discovery.
    """
    __args__ = dict()
    __args__['filter'] = filter
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vra:image/getImage:getImage', __args__, opts=opts, typ=GetImageResult).value

    return AwaitableGetImageResult(
        description=__ret__.description,
        external_id=__ret__.external_id,
        filter=__ret__.filter,
        id=__ret__.id,
        name=__ret__.name,
        private=__ret__.private,
        region=__ret__.region)


@_utilities.lift_output_func(get_image)
def get_image_output(filter: Optional[pulumi.Input[str]] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetImageResult]:
    """
    The `image.get_image` data source can be used to discover the lookup machine images with cloud accounts. This can then be used with resource that require an image. For example, to create an image profile using the `image.Profile` resource.

    ## Example Usage

    This is an example of how to lookup images from a vSphere cloud account.

    ```python
    import pulumi
    import pulumi_vra as vra
    import pulumiverse_vra as vra

    this_v_sphere = vra.cloudaccount.get_v_sphere(name=var["cloud_account"])
    this_region = vra.region.get_region(cloud_account_id=this_v_sphere.id,
        region=var["region"])
    image0 = vra.image.get_image(filter=f"name eq '{var['image_name_0']}' and cloudAccountId eq '{this_v_sphere.id}' and externalRegionId eq '{var['region']}'")
    image1 = vra.image.get_image(filter=f"name eq '{var['image_name_1']}' and cloudAccountId eq '{this_v_sphere.id}' and externalRegionId eq '{var['region']}'")
    this_profile = vra.image.Profile("thisProfile",
        description=var["image_profile_description"],
        region_id=this_region.id,
        image_mappings=[
            vra.image.ProfileImageMappingArgs(
                name=var["image_name_0"],
                image_id=image0.id,
            ),
            vra.image.ProfileImageMappingArgs(
                name=var["image_name_1"],
                image_id=image1.id,
            ),
        ])
    ```


    :param str filter: Search criteria to narrow down the image discovery.
    """
    ...
